devicesinlan_gui - Mariano Muñoz

# NAME

devicesinlan_gui: Busca todos los dispositivos de tu LAN. Después, puedes establecer alias a tus dispositivos conocidos para detectar dispositivos extraños en tu red.

# SYNOPSIS

devicesinlan_gui [--help] [--version] [--debug DEBUG]

# DESCRIPCIÓN

En el menú de la aplicación tienes las siguientes funcionalidades:

Dispositivo > Nuevo escaneado

Searches all devices in tha LAN and show them in a new tab. If some device is not in the known devices list it will be shown with a red background. Devices with a green background are trusted devices

Dispositivos > Muestra la base de datos de dispositivos

Muestra todo los dispositivos conocidos en una nueva pestaña.

Hacer click derecho te permite editar la base de datos de dispositivos conocidos.

Dispositivos > Carga una lista de dispositivos

Carga una lista de dispositivos conocidos en formato xml.

Dispositivos > Grabar lista de dispositivos

Graba la lista de dispositivos conocidos a un fichero xml.

Dispositivos > Borrar la base de datos

Borra todos los dispositivos conocidos.

Esta opción borra todos los dispositivos conocidos de la base de datos.

Configuración > Preferencias

In this dialog you can select your prefered language and you can configure the number of concurrence request.

Ayuda > Ayuda

Muestra esta información de ayuda.

Ayuda > Acerca de

Shows information about DevicesInLAN license and authors.

Ayuda > Busca actualizaciones

Checks for updates in DevicesInLan repository.

Ayuda > Salir

Sale del programa.

Created with libmangenerator at 2018-11-26